@@ -39,10 +39,11 @@ def time_now(time_to_convert = time.time()):
 def unix():
   return int(time.time())
 
-def stopwatch_start(name = "1"):
-  globals()[f"{name}StopwatchStartTime"] = time.time()
-  return = "Started!"
-def stopwatch_stop(name = "1"):
-  stopwatchLength = time.time() - [f"{name}StopwatchStartTime"]
+def stopwatch_start():
+  global stopwatchStartTime
+  stopwatchStartTime = time.time()
+  return "Started!"
+def stopwatch_stop():
+  stopwatchLength = time.time() - stopwatchStartTime
   return stopwatchLength
 
